@@ -229,17 +229,18 @@ class InterrelateContent(Stage):
             digest = manifest['digest']
             for item in man_list:
                 if item.digest == digest:
-                    platform = manifest['platform']
-                    thru = ManifestListManifest(manifest_list=item, image_manifest=dc.content,
-                                                architecture=platform['architecture'],
-                                                os=platform['os'],
-                                                features=platform.get('features', ''),
-                                                variant=platform.get('variant', ''),
-                                                os_version=platform.get('os.version', ''),
-                                                os_features=platform.get('os.features', '')
-                                                )
-                    mlm.append(thru)
                     break
+            platform = manifest['platform']
+            thru = ManifestListManifest(manifest_list=item, image_manifest=dc.content,
+                                        architecture=platform['architecture'],
+                                        os=platform['os'],
+                                        features=platform.get('features', ''),
+                                        variant=platform.get('variant', ''),
+                                        os_version=platform.get('os.version', ''),
+                                        os_features=platform.get('os.features', '')
+                                        )
+            mlm.append(thru)
+
         return mlm
 
 
@@ -248,7 +249,7 @@ class DockerContentSaver(ContentSaver):
     Stage for saving DC.
     """
 
-    async def _pre_save(self, batch):
+    def _pre_save(self, batch):
         """
         Relate manifest to tag before saving tag.
         We need to do it in the pre_save hook because of Tag's uniqueness constraint.
@@ -267,7 +268,7 @@ class DockerContentSaver(ContentSaver):
                 man = Manifest.objects.filter(digest=related_man_id).first()
                 dc.content.tagged_manifest = man
 
-    async def _post_save(self, batch):
+    def _post_save(self, batch):
         """
         Remove tag if it  points to a tagged_manifest=null
 
